package com.zd.laboratory.mapper;

import com.zd.laboratory.domain.LabSafeClassified;

import java.util.List;

/**
 * 安全分级Mapper接口
 *
 * @author zd
 * @date 2021-12-18
 */
public interface LabSafeClassifiedMapper
{
    /**
     * 查询安全分级
     *
     * @param id 安全分级主键
     * @return 安全分级
     */
    public LabSafeClassified selectLabSafeClassifiedById(Long id);

    /**
     * 查询安全分级列表
     *
     * @param labSafeClassified 安全分级
     * @return 安全分级集合
     */
    public List<LabSafeClassified> selectLabSafeClassifiedList(LabSafeClassified labSafeClassified);

    /**
     * 新增安全分级
     *
     * @param labSafeClassified 安全分级
     * @return 结果
     */
    public int insertLabSafeClassified(LabSafeClassified labSafeClassified);

    /**
     * 修改安全分级
     *
     * @param labSafeClassified 安全分级
     * @return 结果
     */
    public int updateLabSafeClassified(LabSafeClassified labSafeClassified);

    /**
     * 删除安全分级
     *
     * @param id 安全分级主键
     * @return 结果
     */
    public int deleteLabSafeClassifiedById(Long id);

    /**
     * 批量删除安全分级
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabSafeClassifiedByIds(Long[] ids);
}
